@@ -96,13 +96,12 @@ void PlasmaWindowModelTest::init()
 {
     delete m_display;
     m_display = new Display(this);
-    m_display->setSocketName(s_socketName);
+    m_display->addSocketName(s_socketName);
     m_display->start();
     QVERIFY(m_display->isRunning());
     m_display->createShm();
-    m_pwInterface = m_display->createPlasmaWindowManagement();
-    m_pwInterface->create();
-    m_plasmaVirtualDesktopManagementInterface = m_display->createPlasmaVirtualDesktopManagement(m_display);
+    m_pwInterface = new PlasmaWindowManagementInterface(m_display, m_display);
+    m_plasmaVirtualDesktopManagementInterface = new PlasmaVirtualDesktopManagementInterface(m_display, m_display);
     m_plasmaVirtualDesktopManagementInterface->createDesktop("desktop1");
     m_plasmaVirtualDesktopManagementInterface->createDesktop("desktop2");
     m_pwInterface->setPlasmaVirtualDesktopManagementInterface(m_plasmaVirtualDesktopManagementInterface);
@@ -146,7 +145,6 @@ void PlasmaWindowModelTest::cleanup()
         variable = nullptr; \
     }
     CLEANUP(m_pw)
-    CLEANUP(m_plasmaVirtualDesktopManagementInterface)
     CLEANUP(m_queue)
     if (m_connection) {
         m_connection->deleteLater();
@@ -159,9 +157,12 @@ void PlasmaWindowModelTest::cleanup()
         m_thread = nullptr;
     }
 
-    CLEANUP(m_pwInterface)
     CLEANUP(m_display)
 #undef CLEANUP
+
+    // these are the children of the display
+    m_plasmaVirtualDesktopManagementInterface = nullptr;
+    m_pwInterface = nullptr;
 }
 
 bool PlasmaWindowModelTest::testBooleanData(PlasmaWindowModel::AdditionalRoles role, void (PlasmaWindowInterface::*function)(bool))
@@ -870,7 +871,7 @@ void PlasmaWindowModelTest::testChangeWindowAfterModelDestroy_data()
 #if KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(5, 28)
     QTest::newRow("iconname" )            << &PlasmaWindow::iconChanged                     << QVariant::fromValue(&PlasmaWindowInterface::setThemedIconName)           << QVariant(QStringLiteral("foo"));
 #endif
-    QTest::newRow("icon" )            << &PlasmaWindow::iconChanged                     << QVariant::fromValue(&PlasmaWindowInterface::setIcon)                     << QVariant::fromValue(QIcon::fromTheme(QStringLiteral("foo")));
+    QTest::newRow("icon" )            << &PlasmaWindow::iconChanged                     << QVariant::fromValue(&PlasmaWindowInterface::setIcon)                     << QVariant(QIcon::fromTheme(QStringLiteral("foo")));
     QTest::newRow("vd")               << &PlasmaWindow::virtualDesktopChanged           << QVariant::fromValue(&PlasmaWindowInterface::setVirtualDesktop)           << QVariant(2u);
     QTest::newRow("unmapped")         << &PlasmaWindow::unmapped                        << QVariant::fromValue(&PlasmaWindowInterface::unmap)                       << QVariant();
 }
@@ -901,6 +902,8 @@ void PlasmaWindowModelTest::testChangeWindowAfterModelDestroy()
         (w->*(setter.value<ServerWindowStringSetter>()))(value.toString());
     } else if (QMetaType::Type(value.type()) == QMetaType::UInt) {
         (w->*(setter.value<ServerWindowQuint32Setter>()))(value.toUInt());
+    } else if (QMetaType::Type(value.type()) == QMetaType::QIcon) {
+        (w->*(setter.value<ServerWindowIconSetter>()))(value.value<QIcon>());
     } else if (!value.isValid()) {
         (w->*(setter.value<ServerWindowVoidSetter>()))();
     }
